##  Add Relations
Add relations for the initial set of fact sheets you’ve imported using one of the following methods.
While linking business capabilities to applications, you automatically get recommendations to help you choose the most relevant ones. It helps improve overall data quality by highlighting gaps and offering recommendations. To learn more, see [Adding Relations](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio275857617a44101499a0c3d00c27319a__adding_and_editing_multiple_relations).
### Add Relations Using Inline Editing
You can add relations to multiple fact sheets using inline editing in the inventory table view. For more details, see [Inline Editing](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD#loioc61816d6a4da4c5fbc9bc6365f2646c2__inline_editing).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiof0af17391f844837b07e62bfae1382fc_LowRes.png)
Adding Relations Using Inline Editing in the Inventory
### Add Relations Using Excel Import
You can add multiple relations at once by importing data through Excel spreadsheets. In the spreadsheet that you plan to import, add relations to the corresponding columns:
  * relApplicationToBusinessCapability
  * relApplicationToOrganization


For details, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e334a7a4410149da8ace4ba60c0bc_LowRes.png)
Adding Relations Through Excel Import
### Add Relations to a Single Fact Sheet
You can manually add relations to a single fact sheet by editing the corresponding fields. On the fact sheet page, locate the relevant section and find the fact sheet to link. For details, see [Adding Relations](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio275857617a44101499a0c3d00c27319a__adding_and_editing_multiple_relations).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio84c58fc0a53d4bc99df2e177ac33ffa1_LowRes.png)
Relations to Business Capabilities on an Application Fact Sheet
